Network | Static smooth curves

## Smooth curves

All the smooth curves in the examples so far have been using dynamic smooth curves. This means that each curve has a support node which takes part in the physics simulation. For large networks or dense clusters, this may not be the ideal solution. To solve this, static smooth curves have been added. The static smooth curves are based only on the positions of the connected nodes. There are multiple ways to determine the way this curve is drawn. This example shows the effect of the different types.
Drag the node around to see how the smooth curves are drawn for each setting. For animated system, we recommend only the continuous mode. In the next example you can see the effect of these methods on a large network. Keep in mind that the direction (the from and to) of the curve matters.
When you select the dynamic type, you can see the interaction with the fixed node and the edge, any other type will not interact with other nodes.

Smooth curve type:

Roundness (0..1):
(0.5 is max roundness for continuous, 1.0 for the others)